#!/bin/sh

# ***************************************************************************
# *                         WARRANTY DISCLAIMER
# ***************************************************************************
# * THE SAMPLE SCRIPT IS BEING PROVIDED TO YOU "AS IS".  DELL DISCLAIMS ANY
# * AND ALL WARRANTIES, EXPRESS, IMPLIED OR STATUTORY, WITH RESPECT TO THE
# * SAMPLE SCRIPT, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND ANY WARRANTY
# * OF NON-INFRINGEMENT. YOU WILL USE THE SAMPLE SCRIPT AT YOUR OWN RISK.
# * DELL SHALL NOT BE LIABLE TO YOU FOR ANY DIRECT OR INDIRECT DAMAGES
# * INCURRED IN USING THE SAMPLE SCRIPT. IN NO EVENT SHALL DELL OR ITS
# * SUPPLIERS BE RESPONSIBLE FOR ANY DIRECT OR INDIRECT DAMAGES WHATSOEVER
# * (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF PROFITS, LOSS OF USE,
# * LOSS OF DATA, BUSINESS INTERRUPTION, OR OTHER PECUNIARY LOSS, NOR FOR
# * PUNITIVE, INCIDENTAL, CONSEQUENTIAL, OR SPECIAL DAMAGES OF ANY KIND,
# * UNDER ANY PART OF THIS AGREEMENT, EVEN IF ADVISED OR AWARE OF THE
# * POSSIBILITY OF SUCH DAMAGES).
# ***************************************************************************

# ***************************************************************************
# * Script Name: dtkrunall.sh
# *
# * Purpose:
# *   This script replicates system BIOS, BMC, DRAC and RAID settings.
# * 
# * Input parameters
# * Accepts the share location where the generated INI files are placed.
# * This is also the default location where the log files will be placed.
# *
# * Tools Used:
# *   syscfg,racadm and raidcfg to capture the system settings
# *
# * External Dependencies
# *   DT_TOOLS, DT_SYSTEMS set by tkenvset.sh let task scripts
# *   know where they can find Toolkit Tools and Configuration scripts.
# *   DT_PLATFORM is set by tkenvset.sh using Platform Discovery.
# *
# * Running the script
# * dtkrunall.sh <sharepath>
# * eg:dtkrunall.sh /opt/dell/toolkit/systems
# *
# #############################################################################


. tkenvset.sh

echo "DTK - Replicating all system information.."


# #############################################################################
#                          USER MODIFICATION REQUIRED
# Below are the user defined variables that this script uses.
# In a full deployment, these variables should be customized to fit the
# user's needs.
# #############################################################################

[ ! -z "$1" ] && DT_SHARE="$1"
if [ ! -e "$DT_SHARE" ]; then
        $DT_SCRIPTS/errhndl.sh "$0" 62
	exit
fi


export sysfile_7g=syscfg_x7xx.ini
export sysfile_8g=syscfg_x8xx.ini
export sysfile_default=syscfg_x9xx.ini
export sysfile_10g=syscfg_xx0x.ini
export sysfile_11g=syscfg_xx1x.ini
export sysfile_12g=syscfg_xx2x.ini
export raccfg_7g=raccfg_rac3.ini
export raccfg_8g=raccfg_rac4.ini

export raidfile_default=raidcfg.ini

# #############################################################################
#export sysname=`syscfg --sysname| awk -F= '{print $2}'| cut -c11-14 `

export svctag=`syscfg --svctag| awk -F= '{print $2}' `
export logfile_default=$DT_PLATFORM-$svctag.txt 

# #############################################################################
# Classification of Dell servers based on generation

gen7=(PE0650 PE1600 PE1650 PE1655 PE2600 PE2650 PE4600 PE6600 PE6650 PE0700 PE0750 PE1750)
gen8=(PE0800 PE0830 PE0840 PE0850 PE0860 PE1800 PE1850 PE1855 PE2800 PE2850 PE6800 PE6850) 
gen9=(PE1900 PE1950 PE1955 PE2900 PE2950 PE2970 PE6950 PE1435 PESC0420 PESC0430 PESC0440 PESC1425 NX1950)
gen10=(PEM20x PER200 PER300 PET300 PER900 PEM600 PEM605 PER805 PER905 PET605 PEM805 PEM905)
gen11=(DX6000 DX6012S FS7500 PER715 PEM710HD PER610 PER710 PET610 PEM610 PEM610x PEM710 PET410 PER410 PET710 PER210 PET310 PET110 PER510 PER310 NX300 DL2100 PEM910 PER810 PER910 PER715 PER815 NX3000 NX300 DL2100 PET110II PER210II PEM915 PER415 PER515)
gen12=(PEM420 PEM520 PEM620 PEM620x PEM720 PEM820 PET320 PET420 PET620 PER320 PER420 PER520 PER620 PER720 PER720P PER720XD PER820 PER920)

# #############################################################################
#
#  Function to find out which generation the Dell server belongs to
#
# #############################################################################
findserver()
{	
	generation="$1"
        shift

	while [ ! -z "$1" ];do
		server="$1"
        	shift
		if [ $server = $DT_PLATFORM ]; then
			if [ $server = 'PE1855' ] || [ $server = 'PE1955' ] || [ $server = 'PEM605' ] || [ $server = 'PEM600' ]|| [ $server = 'PEM805' ]|| [ $server = 'PEM905' ]|| [ $server = 'PEM610' ]|| [ $server = 'PEM710' ] || [ $server = 'PEM610x' ]|| [ $server = 'PEM710HD' ]|| [ $server = 'PEM915' ]|| [ $server = 'PEM520' ]|| [ $server = 'PEM620' ] || [ $server = 'PEM620x' ]|| [ $server = 'PEM420' ]|| [ $server = 'PEM720' ] || [ $server = 'PEM820' ]; then
				export svctag=`syscfg --syssvctag| awk -F= '{print $2}' `
				export logfile_default=$DT_PLATFORM-$svctag.txt 
			fi
			export gen=$generation
		fi	
	done
	
}	

findserver gen7 "${gen7[@]}" 
findserver gen8 "${gen8[@]}" 
findserver gen9 "${gen9[@]}" 
findserver gen10 "${gen10[@]}" 
findserver gen11 "${gen11[@]}" 
findserver gen12 "${gen12[@]}" 

# Fatal error as Dell server generation not found
if [ -z "$gen" ]; then 
	$DT_SCRIPTS/errhndl.sh "$0" 61
	exit 1
fi

case $gen in
	"gen7") 
	if [ ! -e $DT_SHARE/$sysfile_7g ] ; then
	echo "$DT_SHARE/$sysfile_7g : File specified does not exist." >> $DT_SHARE/$logfile_default
	else sh sysrep.sh $DT_SHARE/$sysfile_7g  $DT_SHARE/$logfile_default
        retsyscfg=$?
        fi
	
	if [ ! -e $DT_SHARE/$raidfile_default ] ; then
	echo "$DT_SHARE/$raidfile_default : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh raidrep.sh $DT_SHARE/$raidfile_default $DT_SHARE/$logfile_default
        fi

	if [ ! -e $DT_SHARE/$raccfg_7g ] ; then
	echo "$DT_SHARE/$raccfg_7g : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh racrep.sh  $DT_SHARE/$raccfg_7g >> $DT_SHARE/$logfile_default
    	fi 
	;;	
		
	"gen8") 
	if [ ! -e $DT_SHARE/$sysfile_8g ] ; then
	echo "$DT_SHARE/$sysfile_8g : File specified does not exist." >> $DT_SHARE/$logfile_default
	else sh sysrep.sh $DT_SHARE/$sysfile_8g  $DT_SHARE/$logfile_default
        retsyscfg=$?
        fi	

	if [ ! -e $DT_SHARE/$raidfile_default ] ; then
	echo "$DT_SHARE/$raidfile_default : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh raidrep.sh $DT_SHARE/$raidfile_default $DT_SHARE/$logfile_default
        fi		
	
	if [ ! -e $DT_SHARE/$raccfg_8g ] ; then
	echo "$DT_SHARE/$raccfg_8g : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh racrep.sh  $DT_SHARE/$raccfg_8g >> $DT_SHARE/$logfile_default
    	fi 
    	;;
	
	"gen9")
	if [ ! -e $DT_SHARE/$sysfile_default ] ; then
	echo "$DT_SHARE/$sysfile_default : File specified does not exist." >> $DT_SHARE/$logfile_default
	else sh sysrep.sh $DT_SHARE/$sysfile_default  $DT_SHARE/$logfile_default
        retsyscfg=$?
        fi	

	if [ ! -e $DT_SHARE/$raidfile_default ] ; then
	echo "$DT_SHARE/$raidfile_default : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh raidrep.sh $DT_SHARE/$raidfile_default $DT_SHARE/$logfile_default
        fi	
	;;
		
	"gen10") 
	if [ ! -e $DT_SHARE/$sysfile_10g ] ; then
	echo "$DT_SHARE/$sysfile_10g : File specified does not exist." >> $DT_SHARE/$logfile_default
	else sh sysrep.sh $DT_SHARE/$sysfile_10g  $DT_SHARE/$logfile_default
        retsyscfg=$?
        fi
	
	if [ ! -e $DT_SHARE/$raidfile_default ] ; then
	echo "$DT_SHARE/$raidfile_default : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh raidrep.sh $DT_SHARE/$raidfile_default $DT_SHARE/$logfile_default
        fi	
	;;
	"gen11") 
	if [ ! -e $DT_SHARE/$sysfile_11g ] ; then
	echo "$DT_SHARE/$sysfile_11g : File specified does not exist." >> $DT_SHARE/$logfile_default
	else sh sysrep.sh $DT_SHARE/$sysfile_11g  $DT_SHARE/$logfile_default
        retsyscfg=$?
        fi
	
	if [ ! -e $DT_SHARE/$raidfile_default ] ; then
	echo "$DT_SHARE/$raidfile_default : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh raidrep.sh $DT_SHARE/$raidfile_default $DT_SHARE/$logfile_default
        fi	
	;;

	"gen12") 
	if [ ! -e $DT_SHARE/$sysfile_12g ] ; then
	echo "$DT_SHARE/$sysfile_12g : File specified does not exist." >> $DT_SHARE/$logfile_default
	else sh sysrep.sh $DT_SHARE/$sysfile_12g  $DT_SHARE/$logfile_default
        retsyscfg=$?
        fi
	
	if [ ! -e $DT_SHARE/$raidfile_default ] ; then
	echo "$DT_SHARE/$raidfile_default : File specified does not exist." >> $DT_SHARE/$logfile_default
        else sh raidrep.sh $DT_SHARE/$raidfile_default $DT_SHARE/$logfile_default
        fi	
	;;
	
		*) 	echo Fatal Error! Nothing was executed ;;
esac

exit $retsyscfg
