#!/bin/bash
# ***************************************************************************
# *                         WARRANTY DISCLAIMER
# ***************************************************************************
# * THE SAMPLE SCRIPT IS BEING PROVIDED TO YOU "AS IS".  DELL DISCLAIMS ANY
# * AND ALL WARRANTIES, EXPRESS, IMPLIED OR STATUTORY, WITH RESPECT TO THE
# * SAMPLE SCRIPT, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND ANY WARRANTY
# * OF NON-INFRINGEMENT. YOU WILL USE THE SAMPLE SCRIPT AT YOUR OWN RISK.
# * DELL SHALL NOT BE LIABLE TO YOU FOR ANY DIRECT OR INDIRECT DAMAGES
# * INCURRED IN USING THE SAMPLE SCRIPT. IN NO EVENT SHALL DELL OR ITS
# * SUPPLIERS BE RESPONSIBLE FOR ANY DIRECT OR INDIRECT DAMAGES WHATSOEVER
# * (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF PROFITS, LOSS OF USE,
# * LOSS OF DATA, BUSINESS INTERRUPTION, OR OTHER PECUNIARY LOSS, NOR FOR
# * PUNITIVE, INCIDENTAL, CONSEQUENTIAL, OR SPECIAL DAMAGES OF ANY KIND,
# * UNDER ANY PART OF THIS AGREEMENT, EVEN IF ADVISED OR AWARE OF THE
# * POSSIBILITY OF SUCH DAMAGES).
# ***************************************************************************

# ***************************************************************************
# * Name: errhndl.sh
# *
# * Purpose: 
# *   This script handles errors in Deployment Toolkit Template Scripts 
# *
# * Command Line Arguments
# *   $1 - First argument is the name of the Script where the error occurred
# *   $2 - Second argument is the Index of the Error message
# *
# ***************************************************************************

# Print usage if the script is not called with the correct number of arguments
noarg ()
{
	echo Usage:
	echo 		errhndl Filename ErrorIndex
	exit 2
}

# ***************************************************************************
# TABLE OF ERROR NUMBERS AND STRINGS
# ***************************************************************************

# Total number of messages
total=60

# Initialize the array to contain a default message.
for (( temp=1; temp<=total; temp++ )); do
	msg[$temp]="$1: Unknown Error Code. $2"
done

# WARNINGS - execution is not stopped on warnings
# Codes 1-20 represent Warning Codes
warnstart=1
warnend=20

msg[01]="Log file not specified"
msg[02]="Answer file for unattended installation not specified"
msg[03]="File system type not specified"
msg[04]="RAID Level not specified"
msg[05]="Vdisk name not specified"
msg[06]="Vdisk size not specified"
msg[07]="Detected RAID adapter does not use firmware"
           
# ERRORS - execution is stopped on errors if STOP_ON_ERROR is set TRUE
# Codes 21-40 represent Error Codes.
errstart=21
errnend=50

msg[21]="OS specified not handled"
msg[22]="Adapter ID not specified"
msg[23]="Adisks ID not specified"
msg[24]="Filename not specified"
msg[25]="Hard disk# not specified"
msg[26]="OS not specified"
msg[27]="OS Source path not specified"
msg[28]="Partition size not specified"
msg[29]="Path not specified"
msg[30]="RAC IP not specified"
msg[31]="Configuration script mapping missing"
msg[32]="Tool failed"
msg[33]="RAC configuration file not specified"
msg[34]="This system does not have a RAC"
           
# FATAL ERRORS - execution is always stopped for fatal errors
# Codes 41-60 represent Fatal Error codes.
fatstart=51
fatend=70

msg[51]="Configuration script specified does not exist"
msg[52]="Could not set state configuration byte"
msg[53]="File specified does not exist"
msg[54]="Platform discovery failed"
msg[55]="RAID Adapter ID specified does not exist"
msg[56]="RAID Adapter type unknown"
msg[57]="BIOS capture file not specified"
msg[58]="RAC configuration file does not exist"
msg[59]="BMC capture file not specified"
msg[60]="Partition Failed"
msg[61]="Dell server generation not found"
msg[62]="Share not specified"

# ***************************************************************************

# Check for proper usage of this script
if [[ -z $1 || -z $2 ]]; then
	noarg
fi

# Print the Error Message
echo ${msg[$2]}

# ***************************************************************************
#
# Return Value
#
# retval of
# --------
#	1 means current operation need not be stopped.
#	2 means current operation should be stopped.
#
# retval is
# ---------
#	1 for Warning Codes.
#	1 for Error Codes when $DT_STOP_ON_ERROR is False/unset.
#	2 for Error Codes when $DT_STOP_ON_ERROR is TRUE.
#	2 for all Fatal and other Codes.
#
# ***************************************************************************
retval=2

if [ $2 -le $warnend ]; then
	retval=1
elif [[ $2 -ge $errstart && $2 -le $errend ]]; then
	if [[ ! -z "$DT_STOP_ON_ERROR" && "$DT_STOP_ON_ERROR" = "TRUE" ]]; then
		retval=1
	fi
fi

exit $retval;
